==> haskell-wai-extra-3.0.15.1-5-armv7h.pkg.tar.xz: usr/share/haskell/haskell-wai-extra/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-extra
version: 3.0.15.1
id: wai-extra-3.0.15.1-954bd1f4cbd0dadcc30817e6afe9d17a
key: waiex_25rno0j1wK3JwuVadfOIHi
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provides some basic WAI handlers and middleware.
description:
    Provides basic WAI handler and middleware functionality:
    .
    * WAI Testing Framework
    .
    Hspec testing facilities and helpers for WAI.
    .
    * Event Source/Event Stream
    .
    Send server events to the client. Compatible with the JavaScript
    EventSource API.
    .
    * Accept Override
    .
    Override the Accept header in a request. Special handling for the
    _accept query parameter (which is used throughout WAI override the
    Accept header).
    .
    * Add Headers
    .
    WAI Middleware for adding arbitrary headers to an HTTP request.
    .
    * Clean Path
    .
    Clean a request path to a canonical form.
    .
    * GZip Compression
    .
    Negotiate HTTP payload gzip compression.
    .
    * HTTP Basic Authentication
    .
    WAI Basic Authentication Middleware which uses Authorization header.
    .
    * JSONP
    .
    \"JSON with Padding\" middleware. Automatic wrapping of JSON
    responses to convert into JSONP.
    .
    * Method Override / Post
    .
    Allows overriding of the HTTP request method via the _method query string
    parameter.
    .
    * Request Logging
    .
    Request logging middleware for development and production environments
    .
    * Request Rewrite
    .
    Rewrite request path info based on a custom conversion rules.
    .
    * Stream Files
    .
    Convert ResponseFile type responses into ResponseStream type.
    .
    * Virtual Host
    .
    Redirect incoming requests to a new host based on custom rules.
    .
    .
    API docs and the README are available at <http://www.stackage.org/package/wai-extra>.
category: Web
author: Michael Snoyman
exposed: True
exposed-modules:
    Network.Wai.Handler.CGI Network.Wai.Handler.SCGI Network.Wai.Header
    Network.Wai.Middleware.AcceptOverride
    Network.Wai.Middleware.AddHeaders Network.Wai.Middleware.Approot
    Network.Wai.Middleware.Autohead Network.Wai.Middleware.CleanPath
    Network.Wai.Middleware.Local Network.Wai.Middleware.RequestLogger
    Network.Wai.Middleware.RequestLogger.JSON
    Network.Wai.Middleware.Gzip Network.Wai.Middleware.Jsonp
    Network.Wai.Middleware.MethodOverride
    Network.Wai.Middleware.MethodOverridePost
    Network.Wai.Middleware.Rewrite Network.Wai.Middleware.StripHeaders
    Network.Wai.Middleware.Vhost Network.Wai.Middleware.HttpAuth
    Network.Wai.Middleware.StreamFile
    Network.Wai.Middleware.ForceDomain Network.Wai.Middleware.ForceSSL
    Network.Wai.Middleware.Routed Network.Wai.Parse Network.Wai.Request
    Network.Wai.UrlMap Network.Wai.Test Network.Wai.EventSource
    Network.Wai.EventSource.EventStream
hidden-modules: Network.Wai.Middleware.RequestLogger.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/wai-extra-3.0.15.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/wai-extra-3.0.15.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/wai-extra-3.0.15.1
hs-libraries: HSwai-extra-3.0.15.1-25rno0j1wK3JwuVadfOIHi
depends:
    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
    ansi-terminal-0.6.2.3-7b40b18f4e53e6f53c2ffd807e929ca9
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    case-insensitive-1.2.0.6-f940e4aded76d28f250fda2e1500b30b
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cookie-0.4.2-28e8510d867302127f61174b072159ee
    data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    fast-logger-2.4.6-432abdc0f5b043114ea69b7c4625cae5
    http-types-0.9-abc209b9e91b870b477d7ec7669b4ae8
    iproute-1.7.0-38a0b7111fde75b34af10d9c12292092
    lifted-base-0.2.3.6-9c13caa8bbd360a88b87891885feeeff
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    resourcet-1.1.7.4-51f149abafdcf0369a30d929df00de54
    streaming-commons-0.1.15.5-b71913214a53247591329436a8fa2523
    stringsearch-0.3.6.6-bd5f901f10569d353c3dabbb227e877c
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
    unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
    vault-0.3.0.6-2c2444df5306907b16aaa509d25c29c9
    void-0.7.1-255c5771d2d826ed3cb8a752061ff594
    wai-3.2.1-82fcd8afd3d66bf63829f2c0f9ec2308
    wai-logger-2.2.7-be4dfe43e81d159502c14b31210da2fe
    word8-0.1.2-9a296ac80618be494d93f29b398e749d
    zlib-0.6.1.1-863f5ed4c9ef7e591295c362d5c5d2a5
haddock-interfaces: /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
haddock-html: /usr/share/doc/haskell-wai-extra/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-extra-3.0.15-2-armv7h.pkg.tar.xz: usr/share/haskell/haskell-wai-extra/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-extra
version: 3.0.15
id: wai-extra-3.0.15-954ac840c460f6e3c2fb191ca01c5fce
key: waiex_5XqEGpiYHwy9vrHr9YSBBx
license: MIT
maintainer: michael@snoyman.com
stability: Stable
homepage: http://github.com/yesodweb/wai
synopsis: Provides some basic WAI handlers and middleware.
description:
    Provides basic WAI handler and middleware functionality:
    .
    * WAI Testing Framework
    .
    Hspec testing facilities and helpers for WAI.
    .
    * Event Source/Event Stream
    .
    Send server events to the client. Compatible with the JavaScript
    EventSource API.
    .
    * Accept Override
    .
    Override the Accept header in a request. Special handling for the
    _accept query parameter (which is used throughout WAI override the
    Accept header).
    .
    * Add Headers
    .
    WAI Middleware for adding arbitrary headers to an HTTP request.
    .
    * Clean Path
    .
    Clean a request path to a canonical form.
    .
    * GZip Compression
    .
    Negotiate HTTP payload gzip compression.
    .
    * HTTP Basic Authentication
    .
    WAI Basic Authentication Middleware which uses Authorization header.
    .
    * JSONP
    .
    \"JSON with Padding\" middleware. Automatic wrapping of JSON
    responses to convert into JSONP.
    .
    * Method Override / Post
    .
    Allows overriding of the HTTP request method via the _method query string
    parameter.
    .
    * Request Logging
    .
    Request logging middleware for development and production environments
    .
    * Request Rewrite
    .
    Rewrite request path info based on a custom conversion rules.
    .
    * Stream Files
    .
    Convert ResponseFile type responses into ResponseStream type.
    .
    * Virtual Host
    .
    Redirect incoming requests to a new host based on custom rules.
    .
    .
    API docs and the README are available at <http://www.stackage.org/package/wai-extra>.
category: Web
author: Michael Snoyman
exposed: True
exposed-modules:
    Network.Wai.Handler.CGI Network.Wai.Handler.SCGI Network.Wai.Header
    Network.Wai.Middleware.AcceptOverride
    Network.Wai.Middleware.AddHeaders Network.Wai.Middleware.Approot
    Network.Wai.Middleware.Autohead Network.Wai.Middleware.CleanPath
    Network.Wai.Middleware.Local Network.Wai.Middleware.RequestLogger
    Network.Wai.Middleware.RequestLogger.JSON
    Network.Wai.Middleware.Gzip Network.Wai.Middleware.Jsonp
    Network.Wai.Middleware.MethodOverride
    Network.Wai.Middleware.MethodOverridePost
    Network.Wai.Middleware.Rewrite Network.Wai.Middleware.StripHeaders
    Network.Wai.Middleware.Vhost Network.Wai.Middleware.HttpAuth
    Network.Wai.Middleware.StreamFile
    Network.Wai.Middleware.ForceDomain Network.Wai.Middleware.ForceSSL
    Network.Wai.Middleware.Routed Network.Wai.Parse Network.Wai.Request
    Network.Wai.UrlMap Network.Wai.Test Network.Wai.EventSource
    Network.Wai.EventSource.EventStream
hidden-modules: Network.Wai.Middleware.RequestLogger.Internal
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/wai-extra-3.0.15
library-dirs: /usr/lib/ghc-7.10.3/site-local/wai-extra-3.0.15
data-dir: /usr/share/arm-linux-ghc-7.10.3/wai-extra-3.0.15
hs-libraries: HSwai-extra-3.0.15-5XqEGpiYHwy9vrHr9YSBBx
depends:
    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
    ansi-terminal-0.6.2.3-7b40b18f4e53e6f53c2ffd807e929ca9
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    base64-bytestring-1.0.0.1-7819850819049320f81b6417431cc8a5
    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    case-insensitive-1.2.0.6-c6baeb35be7a5ef7e8151f5e00d87f59
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cookie-0.4.1.6-97fa5cf54d4ed1e2644dbcebe7255b51
    data-default-class-0.0.1-fcbab95490d730dd2489b628499587cd
    deepseq-1.4.1.1-3975618f889b45239daa47b7443eaeee
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    fast-logger-2.4.1-5b4c33804a079c795a3744fd9f8cdcd3
    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
    iproute-1.7.0-38a0b7111fde75b34af10d9c12292092
    lifted-base-0.2.3.6-26b5b3c50c56a653ba3c5b8bce492107
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
    streaming-commons-0.1.15.2-e8e35f9b3c5e3a1a9d565bf7c4ec1900
    stringsearch-0.3.6.6-bd5f901f10569d353c3dabbb227e877c
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unix-2.7.1.0-a583968f8d5891c6bf334fddb26b19a6
    unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
    vault-0.3.0.6-2c2444df5306907b16aaa509d25c29c9
    void-0.7.1-5298c6b3a32576797627b9b87532f9cb
    wai-3.2.0-7ea0a12f4ecd69f2ebdeef193a494430
    wai-logger-2.2.4.1-9478a6051df96b8d5b3214f7fcca2185
    word8-0.1.2-9a296ac80618be494d93f29b398e749d
    zlib-0.6.1.1-863f5ed4c9ef7e591295c362d5c5d2a5
haddock-interfaces: /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
haddock-html: /usr/share/doc/haskell-wai-extra/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
